@@ -1,6 +1,6 @@
 use strict; use warnings;
 package Vroom;
-our $VERSION = '0.37';
+our $VERSION = '0.41';
 use Vroom::Mo;
 
 use File::HomeDir;
@@ -717,6 +717,10 @@ sub padVertical {
     my @lines = split /\n/, $slide;
     my $lines = @lines;
     my $before = int(($self->config->{height} - $lines) / 2) - 1;
+    if ($self->config->{top}) {
+        $before = 3 if $before > 3;
+        $before = 1 if $before < 1;
+    }
     return "\n" x $before . $slide;
 }
 
